==> zarm-2.9.20.tgz: package/es/file-picker/__tests__/index.test.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import { render, mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import { mocked } from 'ts-jest/utils';
import FilePicker from '../index';
import { mockCreateObjectURL, mockResetCreateObjectURL } from '../../../tests/utils';
import handleFileInfo from '../utils/handleFileInfo';
jest.mock('../utils/handleFileInfo');
var mHandleFileInfo = mocked(handleFileInfo);
describe('file picker', function () {
  it('render correctly', function () {
    var props = {
      onChange: jest.fn(),
      children: /*#__PURE__*/React.createElement("button", null, "add")
    };
    var wrapper = render( /*#__PURE__*/React.createElement(FilePicker, props));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
});
describe('file picker event', function () {
  var props = {
    accept: 'image/jpg, image/jpeg, image/gif, image/png',
    onChange: jest.fn(),
    quality: 0.3,
    children: /*#__PURE__*/React.createElement("button", null, "add")
  };
  var mCreateObjectURL = jest.fn();
  var file = new File([''], './test.jpg', {
    type: 'image/jpeg'
  });
  var mFileDetail = {
    file: file,
    fileType: file.type,
    fileName: file.name,
    fileSize: file.size,
    thumbnail: 'data:,'
  };
  beforeAll(function () {
    mockCreateObjectURL(mCreateObjectURL);
  });
  afterAll(function () {
    mockResetCreateObjectURL();
  });
  afterEach(function () {
    jest.clearAllMocks();
  });
  it('select image & onBeforeSelect is not func', function () {
    var _props = _objectSpread(_objectSpread({}, props), {}, {
      multiple: true,
      onBeforeSelect: false
    });

    mHandleFileInfo.mockImplementation(function (_, callback) {
      callback(mFileDetail);
    });
    var wrapper = mount( /*#__PURE__*/React.createElement(FilePicker, _props));
    var mClickEvent = {
      preventDefault: jest.fn()
    };
    wrapper.find('.za-file-picker__input').simulate('click', mClickEvent);
    expect(mClickEvent.preventDefault).not.toBeCalled();
    wrapper.find('.za-file-picker__input').simulate('change', {
      target: {
        files: [file]
      }
    });
    expect(props.onChange).toBeCalledWith([mFileDetail]);
    expect(props.onChange).toBeCalledTimes(1);
  });
  it('should handle change event if files is an array of File instance', function () {
    var getFileInfo;
    mHandleFileInfo.mockImplementation(function (_, callback) {
      getFileInfo = callback;
      callback(mFileDetail);
    });
    var wrapper = mount( /*#__PURE__*/React.createElement(FilePicker, props));
    wrapper.find('.za-file-picker__input').simulate('change', {
      target: {
        files: [file]
      }
    });
    expect(mHandleFileInfo).toBeCalledWith({
      file: file,
      quality: 0.3
    }, getFileInfo);
    expect(props.onChange).toBeCalledWith(mFileDetail);
  });
  it('click children', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(FilePicker, props));
    wrapper.find('button').simulate('click');
    wrapper.find('.za-file-picker__input').simulate('change', {
      target: {
        files: [file]
      }
    });
    expect(props.onChange).toBeCalled();
  });
});
describe('file picker disabled', function () {
  var props = {
    accept: 'image/jpg, image/jpeg, image/gif, image/png',
    onChange: jest.fn(),
    onBeforeSelect: jest.fn(),
    children: /*#__PURE__*/React.createElement("button", null, "foo")
  };
  it('on before select return false', function () {
    var _props = _objectSpread(_objectSpread({}, props), {}, {
      onBeforeSelect: jest.fn(function () {
        return false;
      })
    });

    var wrapper = mount( /*#__PURE__*/React.createElement(FilePicker, _props));
    wrapper.find('.za-file-picker__input').simulate('click');
    expect(props.onChange).not.toHaveBeenCalled();
  });
  it('disabled', function () {
    var _props = _objectSpread(_objectSpread({}, props), {}, {
      disabled: true
    });

    var wrapper = mount( /*#__PURE__*/React.createElement(FilePicker, _props));
    wrapper.find('.za-file-picker__input').simulate('click');
    expect(props.onChange).not.toHaveBeenCalled();
  });
});

==> zarm-3.1.3.tgz: package/es/file-picker/__tests__/index.test.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import { fireEvent, render } from '@testing-library/react';
import { mocked } from 'ts-jest/utils';
import FilePicker from '../index';
import { mockCreateObjectURL, mockResetCreateObjectURL } from '../../../tests/utils';
import handleFileInfo from '../utils/handleFileInfo';
jest.mock('../utils/handleFileInfo');
var mHandleFileInfo = mocked(handleFileInfo);
describe('file picker', function () {
  it('render correctly', function () {
    var props = {
      onChange: jest.fn(),
      children: /*#__PURE__*/React.createElement("button", null, "add")
    };
    var wrapper = render( /*#__PURE__*/React.createElement(FilePicker, props));
    expect(wrapper.asFragment()).toMatchSnapshot();
  });
});
describe('file picker event', function () {
  var props = {
    accept: 'image/jpg, image/jpeg, image/gif, image/png',
    onChange: jest.fn(),
    quality: 0.3,
    children: /*#__PURE__*/React.createElement("button", null, "add")
  };
  var mCreateObjectURL = jest.fn();
  var file = new File([''], './test.jpg', {
    type: 'image/jpeg'
  });
  var mFileDetail = {
    file: file,
    fileType: file.type,
    fileName: file.name,
    fileSize: file.size,
    thumbnail: 'data:,'
  };
  beforeAll(function () {
    mockCreateObjectURL(mCreateObjectURL);
  });
  afterAll(function () {
    mockResetCreateObjectURL();
  });
  afterEach(function () {
    jest.clearAllMocks();
  });
  it('select image & onBeforeSelect is not func', function () {
    var _props = _objectSpread(_objectSpread({}, props), {}, {
      multiple: true,
      onBeforeSelect: false
    });

    mHandleFileInfo.mockImplementation(function (_, callback) {
      callback(mFileDetail);
    });

    var _render = render( /*#__PURE__*/React.createElement(FilePicker, _props)),
        container = _render.container;

    var mClickEvent = {
      preventDefault: jest.fn()
    };
    var fileInput = container.querySelectorAll('.za-file-picker__input')[0];
    fireEvent.change(fileInput, mClickEvent);
    expect(mClickEvent.preventDefault).not.toBeCalled();
    fireEvent.change(fileInput, {
      target: {
        files: [file]
      }
    });
    expect(props.onChange).toBeCalledWith([mFileDetail]);
    expect(props.onChange).toBeCalledTimes(1);
  });
  it('should handle change event if files is an array of File instance', function () {
    var getFileInfo;
    mHandleFileInfo.mockImplementation(function (_, callback) {
      getFileInfo = callback;
      callback(mFileDetail);
    });

    var _render2 = render( /*#__PURE__*/React.createElement(FilePicker, props)),
        container = _render2.container;

    var fileInput = container.querySelectorAll('.za-file-picker__input')[0];
    fireEvent.change(fileInput, {
      target: {
        files: [file]
      }
    });
    expect(mHandleFileInfo).toBeCalledWith({
      file: file,
      quality: 0.3
    }, getFileInfo);
    expect(props.onChange).toBeCalledWith(mFileDetail);
  });
  it('click children', function () {
    var _render3 = render( /*#__PURE__*/React.createElement(FilePicker, props)),
        container = _render3.container;

    var fileInput = container.querySelectorAll('.za-file-picker__input')[0];
    fireEvent.change(fileInput, {
      target: {
        files: [file]
      }
    });
    expect(props.onChange).toBeCalled();
  });
});
describe('file picker disabled', function () {
  var props = {
    accept: 'image/jpg, image/jpeg, image/gif, image/png',
    onChange: jest.fn(),
    onBeforeSelect: jest.fn(),
    children: /*#__PURE__*/React.createElement("button", null, "foo")
  };
  it('on before select return false', function () {
    var _props = _objectSpread(_objectSpread({}, props), {}, {
      onBeforeSelect: jest.fn(function () {
        return false;
      })
    });

    var _render4 = render( /*#__PURE__*/React.createElement(FilePicker, _props)),
        container = _render4.container;

    var fileInput = container.querySelectorAll('.za-file-picker__input')[0];
    fireEvent.change(fileInput);
    expect(props.onChange).not.toHaveBeenCalled();
  });
  it('disabled', function () {
    var _props = _objectSpread(_objectSpread({}, props), {}, {
      disabled: true
    });

    var _render5 = render( /*#__PURE__*/React.createElement(FilePicker, _props)),
        container = _render5.container;

    var fileInput = container.querySelectorAll('.za-file-picker__input')[0];
    fireEvent.change(fileInput);
    expect(props.onChange).not.toHaveBeenCalled();
  });
});
